AbstractRepositorySingleton class abstract

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

flush(String? appId) → void
followingDashboardRepository(String? appId) → FollowingDashboardRepository?
followingRepository(String? appId) → FollowingRepository?
followRequestRepository(String? appId) → FollowRequestRepository?
followRequestsDashboardRepository(String? appId) → FollowRequestsDashboardRepository?
inviteDashboardRepository(String? appId) → InviteDashboardRepository?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

collections ↔ List<MemberCollectionInfo>
getter/setter pair
singleton ↔ AbstractRepositorySingleton
getter/setter pair