FollowingArrayModel class

Constructors

FollowingArrayModel({required String documentID, required String appId, List<String>? followers})

Properties

appId ↔ String
getter/setter pairoverride
documentID ↔ String
getter/setter pairoverride
followers ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? appId, List<String>? followers}) → FollowingArrayModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → FollowingArrayEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(String documentID, FollowingArrayEntity? entity) → Future<FollowingArrayModel?>
fromEntityPlus(String documentID, FollowingArrayEntity? entity, {String? appId}) → Future<FollowingArrayModel?>

Constants

id → const String
packageName → const String