RepositorySingleton class

Inheritance

Constructors

RepositorySingleton()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

flush(String? appId) → void
inherited
followingDashboardRepository(String? appId) → FollowingDashboardRepository?
override
followingRepository(String? appId) → FollowingRepository?
override
followRequestRepository(String? appId) → FollowRequestRepository?
override
followRequestsDashboardRepository(String? appId) → FollowRequestsDashboardRepository?
override
inviteDashboardRepository(String? appId) → InviteDashboardRepository?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited